Rulu
====

Rulu provides a Pythonic, declarative interface for building rule-based expert systems. 

Rulu is implemented over [clipspy](https://github.com/noxdafox/clipspy), the Python wrapper of the [CLIPS](http://http://clipsrules.sourceforge.net) expert system library.  

Installation
============
`pip install rulu`

Documentation
=============
Rulu documentation may be found [here](http://rulu.readthedocs.org/en/latest/)
